#!/usr/bin/env sh
# SPDX-License-Identifier: AGPL-3.0-or-later
# SPDX-FileCopyrightText: 2021-2024 JayVii <jayvii[AT]posteo[DOT]de>

# $1 - HTML Root
# $2 - prv/pub

# Error out if not all options are given
if [ -z "$2" ]; then
    echo "Usage:
git_update_index_html.sh \\
    \"/var/www/git.example.git\" \\
    \"pub\"
    "
    exit 1;
fi

# find respositories, sort them by update time
REPOS=`find "${1}"/"${2}" \
    -maxdepth 1 \
    -type d \
    -name "*.git" \
    -printf "%T+\t%p\n" | \
    sort -r | \
    awk '{print $2}'`

# build index HTML
stagit-index $REPOS > "${1}/${2}/index.html"

# ensure that repos link to index rather than log
sed -e 's/log\.html/index.html/g' -i "${1}/${2}/index.html"

# linking assets
ln -sf "${1}/assets/style.css" "${1}/${2}/style.css"
ln -sf "${1}/assets/favicon.png" "${1}/${2}/favicon.png"
ln -sf "${1}/assets/favicon.png" "${1}/${2}/logo.png"

# link htaccess
ln -sf "${1}/htaccess" "${1}/.htaccess"

# Modules ----------------------------------------------------------------------

# Activity module
if [ -f "${1}/bin/activity.sh" ]; then
    ACTIVITY_HTML=`${1}/bin/activity.sh $REPOS`
    sed "/<div id=\"content\">/a${ACTIVITY_HTML}" \
        -i "${1}/${2}/index.html"
fi
